@@ -5,22 +5,18 @@
 #
 # Copyright 2006 YAMASHINA Hio
 # -----------------------------------------------------------------------------
-# $Id: MY_Metafile.pm 5219 2008-01-16 06:54:15Z hio $
+# $Id: MY_Metafile.pm,v 1.1 2007/01/15 09:05:49 hio Exp $
 # -----------------------------------------------------------------------------
 package ExtUtils::MY_Metafile;
 use strict;
-#use warnings; # warnings was first released with perl 5.006
+use warnings;
 use ExtUtils::MakeMaker;
 
-use vars qw($VERSION @EXPORT %META_PARAMS $DIAG_VERSION $DEFAULT_META_SPEC_VERSION);
+our $VERSION = '0.07';
+our @EXPORT = qw(my_metafile);
 
-$VERSION = '0.08';
-@EXPORT = qw(my_metafile);
-
-%META_PARAMS; # DISTNAME(pkgname)=>HASHREF.
-$DIAG_VERSION and &_diag_version;
-
-$DEFAULT_META_SPEC_VERSION = '1.3';
+our %META_PARAMS; # DISTNAME(pkgname)=>HASHREF.
+our $DIAG_VERSION and &_diag_version;
 
 1;
 
@@ -139,14 +135,14 @@ sub _gen_meta_yml
 	# from MakeMaker-6.30.
 	my $this = shift;
 	my $param = shift;
-	my $check_meta_spec = 1;
+	my $check_mete_spec = 1;
 	if( !$param )
 	{
 		$param = $META_PARAMS{$this->{DISTNAME}} || $META_PARAMS{''};
 		if( !$param )
 		{
 			$param = {};
-			$check_meta_spec = 0;
+			$check_mete_spec = 0;
 		}
 	}
 	if( $META_PARAMS{':all'} )
@@ -154,22 +150,7 @@ sub _gen_meta_yml
 		# special key.
 		$param = { %{$META_PARAMS{':all'}}, %$param };
 	}
-
-	# meta_spec and meta_spec_version.
-	my $meta_spec = $param->{meta_spec} || $param->{'meta-spec'};
-	if($param->{meta_spec} && $param->{'meta-spec'} )
-	{
-		warn "both meta_spec and meta-spec exist.\n";
-	}
-	$meta_spec &&= {%$meta_spec}; # sharrow-copy.
-	$meta_spec ||= {};
-	if( exists($param->{meta_spec_version}) && exists($meta_spec->{version}) )
-	{
-		warn "both meta_spec_vesrion and meta_spec.version exist.\n";
-	}
-	$meta_spec->{version} ||= $param->{meta_spec_version} || $DEFAULT_META_SPEC_VERSION;
-	$meta_spec->{url}     ||= "http://module-build.sourceforge.net/META-spec-v$meta_spec->{version}.html";
-
+	
 	# requires:, build_requires:
 	my $requires_to_yaml = sub{
 		my $key = shift;
@@ -202,21 +183,12 @@ sub _gen_meta_yml
 	chomp $no_index;
 	if( $param->{no_index} && !$ENV{NO_NO_INDEX_CHECK} )
 	{
-		my $warned;
 		foreach my $key (keys %{$param->{no_index}})
 		{
-			# dir is in spec-v1.2, directory is from spec-v1.3.
-			if( $key eq 'dir' && $meta_spec->{version}>=1.3 )
-			{
-				$warned ||= print STDERR "\n";
-				warn "$key should be `directory' in META-spec-v1.3 and later.\n";
-				next;
-			}
+			# dir is in spec-v1.2, directory is from spec-v1.3? (blead).
 			$key =~ /^(file|dir|directory|package|namespace)$/ and next;
-			$warned ||= print STDERR "\n";
 			warn "$key is invalid field for no_index.\n";
 		}
-		$warned and print STDERR "\n";
 	}
 	
 	# abstract is from file.
@@ -244,9 +216,7 @@ sub _gen_meta_yml
 	chomp $abstract;
 	
 	# build yaml object as hash.
-	my $yaml = {}; # key=>"value as yaml-text".
-
-	# first, set from arguments for WriteMakefile().
+	my $yaml = {};
 	$yaml->{name}         = $this->{DISTNAME};
 	$yaml->{version}      = $this->{VERSION};
 	$yaml->{version_from} = $this->{VERSION_FROM};
@@ -268,16 +238,15 @@ sub _gen_meta_yml
 	
 	$yaml->{distribution_type} = 'distribution_type: module';
 	$yaml->{generated_by} = "generated_by: ExtUtils::MY_Metafile version $VERSION, EUMM-$ExtUtils::MakeMaker::VERSION.";
-
 	$yaml->{'meta-spec'}  = "meta-spec:\n";
-	$yaml->{'meta-spec'} .= "  version: ".delete($meta_spec->{version})."\n";
-	$yaml->{'meta-spec'} .= "  url: ".delete($meta_spec->{url})."\n";
-
-	# next, set from arguments for my_metafile().
+	$yaml->{'meta-spec'} .= "  version: 1.2\n";
+	$yaml->{'meta-spec'} .= "  url: http://module-build.sourceforge.net/META-spec-v1.2.html\n";
+	
+	# customize yaml.
 	my $extras = {};
 	foreach my $key (sort keys %$param)
 	{
-		grep{$key eq $_} qw(no_index requires build_requires meta_spec meta-spec meta_spec_version) and next;
+		grep{$key eq $_} qw(no_index requires build_requires) and next;
 		my $line = _yaml_out->({$key=>$param->{$key}});
 		if( exists($yaml->{$key}) )
 		{
@@ -289,22 +258,16 @@ sub _gen_meta_yml
 		}
 	}
 	$yaml->{extras} = join('', map{$extras->{$_}} sort keys %$extras);
-
-	# then, check required keys by yaml-spec.
+	
 	my @required_keys = qw(meta-spec name version abstract author license generated_by);
 	foreach my $key (@required_keys)
 	{
-		$check_meta_spec or next;
+		$check_mete_spec or next;
 		my $ok = $yaml->{$key} && $yaml->{$key}=~/\w/;
 		$ok  ||= $extras->{$key} and next;
 		warn "$key is required for meta-spec v1.2 ($this->{DISTNAME}).\n";
 	}
-
-	if( exists($param->{license}) && exists($this->{LICENSE}) && $param->{license} ne $this->{LICENSE} )
-	{
-		warn "WriteMakefile.LICENSE ($this->{LICENSE}) is different from my_metafile.license ($param->{license}).";
-	}
-
+	
 	$yaml->{license} ||= 'license: unknown';
 	foreach my $key (keys %$yaml)
 	{
@@ -312,13 +275,7 @@ sub _gen_meta_yml
 		$yaml->{$key} ||= "#$key:";
 	}
 	$yaml->{extras} &&= "\n# extras.\n$yaml->{extras}";
-
-	foreach my $key (qw(abstract license))
-	{
-		my $pad = ' 'x(12-length($key));
-		$yaml->{$key} =~ s/^$key: +(.+)\z/$key:$pad $1/;
-	}
-
+	
 	# packing into singple text.
 	my $meta = <<YAML;
 # http://module-build.sourceforge.net/META-spec.html
@@ -381,7 +338,6 @@ sub _yaml_out
 # -----------------------------------------------------------------------------
 # End of Code.
 # -----------------------------------------------------------------------------
-
 __END__
 
 =encoding utf8
@@ -403,7 +359,7 @@ ExtUtils::MY_Metafile - META.yml customize with ExtUtil::MakeMaker
 
 =head1 VERSION
 
-Version 0.08
+Version 0.07
 
 
 =head1 SYNOPSIS
@@ -461,8 +417,8 @@ Some parameters are checked automatically.
 =item no_index
 
 If you not specify C<directory> parameter for C<no_index> and
-there are any directory of F<inc t ex eg example examples
-sample samples demo demos>, they are set as it.
+there is directory C<inc t ex eg example examples sample samples
+demo demos>, they are set as it.
 
 
 =item requires
